@@ -212,17 +212,20 @@ my %_revinfostash = (
         '4'  => 'Raspberry Pi 2 Model B',               # 04
         '5'  => 'Raspberry Pi Alpha',                   # 05
         '6'  => 'Raspberry Pi Compute Module 1',        # 06
-        '7'  => 'Raspberry Pi Unknown Model 07',        # 07
+        '7'  => 'UNKNOWN Raspberry Pi Model 07',        # 07
         '8'  => 'Raspberry Pi 3 Model B',               # 08
         '9'  => 'Raspberry Pi Zero',                    # 09
         '10' => 'Raspberry Pi Compute Module 3',        # 0A
-        '11' => 'UNKNOWN Rasberry Pi Model 11',         # 0B
+        '11' => 'UNKNOWN Raspberry Pi Model 11',        # 0B
         '12' => 'Raspberry Pi Zero W',                  # 0C
         '13' => 'Raspberry Pi 3 Model B Plus',          # 0D
         '14' => 'Raspberry Pi 3 Model A Plus',          # 0E
         '15' => 'UNKNOWN Rasberry Pi Model 15',         # 0F
         '16' => 'Raspberry Pi Compute Module 3 Plus',   # 10
         '17' => 'Raspberry Pi 4 Model B',               # 11
+        '18' => 'UNKNOWN Rasberry Pi Model 18',         # 12
+        '19' => 'Raspberry Pi Model 400',               # 13
+        '20' => 'Raspberry Pi Compute Module 4',        # 14
     },
     board_type => {
         '0'  => $btype2,
@@ -243,6 +246,9 @@ my %_revinfostash = (
         '15' => $btype3,
         '16' => $btype4,
         '17' => $btype3,
+        '18' => $btype3,
+        '19' => $btype3,
+        '20' => $btype4,
     },
     release => {
         '0'  => 'Q1 2013',
@@ -263,6 +269,9 @@ my %_revinfostash = (
         '15' => 'unknown',
         '16' => 'Q1 2019',
         '17' => 'Q2 2019',
+        '18' => 'unknown',
+        '19' => 'Q4 2020',
+        '20' => 'Q4 2020',
     },
     extended_release => {
         'a03111' => 'Q2 2019', #	4B	1.1	1GB	Sony UK
